@@ -24,27 +24,27 @@
 #define BYTETABLETOOLVIEWFACTORY_H
 
 // lib
-#include "oktetakastencontrollers_export.h"
-// Kasten core
-#include <abstracttoolviewfactory.h>
+#include <kasten/okteta/oktetakastencontrollers_export.h>
+// Kasten gui
+#include <kasten/abstracttoolviewfactory.h>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class OKTETAKASTENCONTROLLERS_EXPORT ByteTableToolViewFactory : public AbstractToolViewFactory
 {
   public:
     ByteTableToolViewFactory();
-    virtual ~ByteTableToolViewFactory();
+    ~ByteTableToolViewFactory() override;
 
   public: // AbstractToolViewFactory API
-    virtual AbstractToolView* create( AbstractTool* tool );
+    AbstractToolView* create( AbstractTool* tool ) override;
 
-    virtual QString iconName() const;
-    virtual QString title() const;
-    virtual QString id() const;
-    virtual SidePosition defaultPosition() const;
+    QString iconName() const override;
+    QString title() const override;
+    QString id() const override;
+    SidePosition defaultPosition() const override;
 };
 
 }
