@@ -40,8 +40,8 @@ static const int modifiedPixmapWidth = 16;
 
 
 ModifiedBarController::ModifiedBarController( StatusBar* statusBar )
-  : mDocument( 0 )
-  , mSynchronizer( 0 )
+  : mDocument( nullptr )
+  , mSynchronizer( nullptr )
 {
     // TODO: depend an statusbar height
     const QSize modifiedPixmapSize = QSize(modifiedPixmapWidth, modifiedPixmapWidth);
@@ -56,13 +56,13 @@ ModifiedBarController::ModifiedBarController( StatusBar* statusBar )
     mRemoteStateLabel->setFixedSize( modifiedPixmapSize );
     statusBar->addWidget( mRemoteStateLabel );
 
-    setTargetModel( 0 );
+    setTargetModel( nullptr );
 }
 
 
 void ModifiedBarController::setTargetModel( AbstractModel* model )
 {
-    AbstractDocument* newDocument = model ? model->findBaseModel<AbstractDocument*>() : 0;
+    AbstractDocument* newDocument = model ? model->findBaseModel<AbstractDocument*>() : nullptr;
 
     if( mDocument == newDocument )
         return;
@@ -73,14 +73,14 @@ void ModifiedBarController::setTargetModel( AbstractModel* model )
 
     if( mDocument )
     {
-        connect( mDocument, SIGNAL(synchronizerChanged(Kasten::AbstractModelSynchronizer*)),
-                            SLOT(onSynchronizerChanged(Kasten::AbstractModelSynchronizer*)) );
+        connect( mDocument, &Kasten::AbstractDocument::synchronizerChanged,
+                 this,      &ModifiedBarController::onSynchronizerChanged );
     }
 
     mLocalStateLabel->setEnabled( mDocument );
     mRemoteStateLabel->setEnabled( mDocument );
 
-    onSynchronizerChanged( mDocument ? mDocument->synchronizer() : 0 );
+    onSynchronizerChanged( mDocument ? mDocument->synchronizer() : nullptr );
 }
 
 
@@ -109,12 +109,12 @@ void ModifiedBarController::onLocalSyncStateChanged( LocalSyncState localSyncSta
 void ModifiedBarController::onRemoteSyncStateChanged( RemoteSyncState remoteSyncState )
 {
     const char* const iconName =
-        ( mSynchronizer == 0 ) ?                   "document-new" :
+        ( ! mSynchronizer ) ?                      "document-new" :
         ( remoteSyncState == RemoteHasChanges ) ?  "document-save" :
         ( remoteSyncState == RemoteDeleted ) ?     "edit-delete" :
         ( remoteSyncState == RemoteUnknown ) ?     "flag-yellow" :
         ( remoteSyncState == RemoteUnreachable ) ? "network-disconnect" :
-        /* else */                                 0;
+        /* else */                                 nullptr;
 
     // TODO: depend an statusbar height
     const QPixmap pixmap = iconName ?
@@ -137,17 +137,18 @@ void ModifiedBarController::onSynchronizerChanged( AbstractModelSynchronizer* ne
     if( mSynchronizer )
     {
         if( ! oldSynchronizer )
-            mDocument->disconnect( this, SLOT(onContentFlagsChanged(Kasten::ContentFlags)) );
+            disconnect( mDocument, &Kasten::AbstractDocument::contentFlagsChanged,
+                        this, &ModifiedBarController::onContentFlagsChanged );
 
         localState = mSynchronizer->localSyncState();
         remoteState = mSynchronizer->remoteSyncState();
 
-        connect( mSynchronizer, SIGNAL(localSyncStateChanged(Kasten::LocalSyncState)),
-                 SLOT(onLocalSyncStateChanged(Kasten::LocalSyncState)) );
-        connect( mSynchronizer, SIGNAL(remoteSyncStateChanged(Kasten::RemoteSyncState)),
-                 SLOT(onRemoteSyncStateChanged(Kasten::RemoteSyncState)) );
-        connect( mSynchronizer, SIGNAL(destroyed(QObject*)),
-                                SLOT(onSynchronizerDeleted(QObject*)) );
+        connect( mSynchronizer, &Kasten::AbstractModelSynchronizer::localSyncStateChanged,
+                 this, &ModifiedBarController::onLocalSyncStateChanged );
+        connect( mSynchronizer, &Kasten::AbstractModelSynchronizer::remoteSyncStateChanged,
+                 this, &ModifiedBarController::onRemoteSyncStateChanged );
+        connect( mSynchronizer, &QObject::destroyed,
+                 this, &ModifiedBarController::onSynchronizerDeleted );
     }
     else if( mDocument )
     {
@@ -156,8 +157,8 @@ void ModifiedBarController::onSynchronizerChanged( AbstractModelSynchronizer* ne
         // TODO: onRemoteSyncStateChanged(...) checks for mSynchronizer and ignores this
         remoteState = RemoteInSync;
 
-        connect( mDocument, SIGNAL(contentFlagsChanged(Kasten::ContentFlags)),
-                 SLOT(onContentFlagsChanged(Kasten::ContentFlags)) );
+        connect( mDocument, &Kasten::AbstractDocument::contentFlagsChanged,
+                 this, &ModifiedBarController::onContentFlagsChanged );
     }
     else
     {
@@ -175,11 +176,11 @@ void ModifiedBarController::onSynchronizerDeleted( QObject* synchronizer )
     if( synchronizer != mSynchronizer )
         return;
 
-    mSynchronizer = 0;
+    mSynchronizer = nullptr;
 
     // switch to document state
-    connect( mDocument, SIGNAL(contentFlagsChanged(Kasten::ContentFlags)),
-             SLOT(onContentFlagsChanged(Kasten::ContentFlags)) );
+    connect( mDocument, &Kasten::AbstractDocument::contentFlagsChanged,
+             this, &ModifiedBarController::onContentFlagsChanged );
 
     onContentFlagsChanged( mDocument->contentFlags() );
         // TODO: onRemoteSyncStateChanged(...) checks for mSynchronizer and ignores the parameter
